MKUserLocationView

Struct MKUserLocationView 

pub struct MKUserLocationView { /* private fields */ }
Available on macOS and crate feature MKAnnotationView and crate feature MKUserLocationView and crate feature objc2-app-kit only.
Implementations

Source

impl MKUserLocationView

Methods declared on superclass MKAnnotationView.

pub unsafe fn initWithAnnotation_reuseIdentifier( this: Allocated<Self>, annotation: Option<&ProtocolObject<dyn MKAnnotation>>, reuse_identifier: Option<&NSString>, ) -> Retained<Self>

Available on crate feature MKAnnotation only.
pub unsafe fn initWithCoder( this: Allocated<Self>, a_decoder: &NSCoder, ) -> Option<Retained<Self>>

Safety

a_decoder possibly has further requirements.

Source

impl MKUserLocationView

Methods declared on superclass NSView.

pub unsafe fn initWithFrame( this: Allocated<Self>, frame_rect: NSRect, ) -> Retained<Self>

Source

impl MKUserLocationView

Methods declared on superclass NSResponder.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl MKUserLocationView

Methods declared on superclass NSObject.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = MKAnnotationView>

pub unsafe fn reuseIdentifier(&self) -> Option<Retained<NSString>>

pub unsafe fn prepareForReuse(&self)

pub unsafe fn prepareForDisplay(&self)

pub unsafe fn annotation( &self, ) -> Option<Retained<ProtocolObject<dyn MKAnnotation>>>

Available on crate feature MKAnnotation only.
pub unsafe fn setAnnotation( &self, annotation: Option<&ProtocolObject<dyn MKAnnotation>>, )

Available on crate feature MKAnnotation only.

Setter for annotation.

pub unsafe fn image(&self) -> Option<Retained<NSImage>>

pub unsafe fn setImage(&self, image: Option<&NSImage>)

Setter for image.

pub unsafe fn centerOffset(&self) -> CGPoint

Available on crate feature objc2-core-foundation only.
pub unsafe fn setCenterOffset(&self, center_offset: CGPoint)

Available on crate feature objc2-core-foundation only.

Setter for centerOffset.

pub unsafe fn accessoryOffset(&self) -> CGPoint

Available on crate feature objc2-core-foundation only.
pub unsafe fn setAccessoryOffset(&self, accessory_offset: CGPoint)

Available on crate feature objc2-core-foundation only.

Setter for accessoryOffset.

pub unsafe fn calloutOffset(&self) -> CGPoint

Available on crate feature objc2-core-foundation only.
pub unsafe fn setCalloutOffset(&self, callout_offset: CGPoint)

Available on crate feature objc2-core-foundation only.

Setter for calloutOffset.

pub unsafe fn leftCalloutOffset(&self) -> CGPoint

Available on crate feature objc2-core-foundation only.
pub unsafe fn setLeftCalloutOffset(&self, left_callout_offset: CGPoint)

Available on crate feature objc2-core-foundation only.

Setter for leftCalloutOffset.

pub unsafe fn rightCalloutOffset(&self) -> CGPoint

Available on crate feature objc2-core-foundation only.
pub unsafe fn setRightCalloutOffset(&self, right_callout_offset: CGPoint)

Available on crate feature objc2-core-foundation only.

Setter for rightCalloutOffset.

pub unsafe fn isEnabled(&self) -> bool

pub unsafe fn setEnabled(&self, enabled: bool)

Setter for isEnabled.

pub unsafe fn isHighlighted(&self) -> bool

pub unsafe fn setHighlighted(&self, highlighted: bool)

Setter for isHighlighted.

pub unsafe fn isSelected(&self) -> bool

pub unsafe fn setSelected(&self, selected: bool)

Setter for isSelected.

pub unsafe fn setSelected_animated(&self, selected: bool, animated: bool)

pub unsafe fn canShowCallout(&self) -> bool

pub unsafe fn setCanShowCallout(&self, can_show_callout: bool)

Setter for canShowCallout.

pub unsafe fn leftCalloutAccessoryView(&self) -> Option<Retained<NSView>>

pub unsafe fn setLeftCalloutAccessoryView( &self, left_callout_accessory_view: Option<&NSView>, )

pub unsafe fn rightCalloutAccessoryView(&self) -> Option<Retained<NSView>>

pub unsafe fn setRightCalloutAccessoryView( &self, right_callout_accessory_view: Option<&NSView>, )

pub unsafe fn detailCalloutAccessoryView(&self) -> Option<Retained<NSView>>

pub unsafe fn setDetailCalloutAccessoryView( &self, detail_callout_accessory_view: Option<&NSView>, )

pub unsafe fn isDraggable(&self) -> bool

pub unsafe fn setDraggable(&self, draggable: bool)

Setter for isDraggable.

pub unsafe fn dragState(&self) -> MKAnnotationViewDragState

pub unsafe fn setDragState(&self, drag_state: MKAnnotationViewDragState)

Setter for dragState.

pub unsafe fn setDragState_animated( &self, new_drag_state: MKAnnotationViewDragState, animated: bool, )

pub unsafe fn clusteringIdentifier(&self) -> Option<Retained<NSString>>

pub unsafe fn setClusteringIdentifier( &self, clustering_identifier: Option<&NSString>, )

Setter for clusteringIdentifier.

This is copied when set.

pub unsafe fn clusterAnnotationView(&self) -> Option<Retained<MKAnnotationView>>

pub unsafe fn displayPriority(&self) -> MKFeatureDisplayPriority

pub unsafe fn setDisplayPriority( &self, display_priority: MKFeatureDisplayPriority, )

Setter for displayPriority.

pub unsafe fn zPriority(&self) -> MKAnnotationViewZPriority

pub unsafe fn setZPriority(&self, z_priority: MKAnnotationViewZPriority)

Setter for zPriority.

pub unsafe fn selectedZPriority(&self) -> MKAnnotationViewZPriority

pub unsafe fn setSelectedZPriority( &self, selected_z_priority: MKAnnotationViewZPriority, )

Setter for selectedZPriority.

pub unsafe fn collisionMode(&self) -> MKAnnotationViewCollisionMode

pub unsafe fn setCollisionMode( &self, collision_mode: MKAnnotationViewCollisionMode, )

Setter for collisionMode.

Methods from Deref<Target = NSView>

pub unsafe fn superview(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn subviews(&self) -> Retained<NSArray<NSView>>

Available on crate feature NSResponder only.
pub fn setSubviews(&self, subviews: &NSArray<NSView>)

Available on crate feature NSResponder only.

Setter for subviews.

This is copied when set.

pub fn isDescendantOf(&self, view: &NSView) -> bool

Available on crate feature NSResponder only.
pub fn ancestorSharedWithView(&self, view: &NSView) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn opaqueAncestor(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn isHidden(&self) -> bool

Available on crate feature NSResponder only.
pub fn setHidden(&self, hidden: bool)

Available on crate feature NSResponder only.

Setter for isHidden.

pub fn isHiddenOrHasHiddenAncestor(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn getRectsBeingDrawn_count( &self, rects: *mut *const CGRect, count: *mut isize, )

Available on crate feature NSResponder only.
Safety
  • rects must be a valid pointer or null.
  • count must be a valid pointer or null.
pub fn needsToDrawRect(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn wantsDefaultClipping(&self) -> bool

Available on crate feature NSResponder only.
pub fn viewDidHide(&self)

Available on crate feature NSResponder only.
pub fn viewDidUnhide(&self)

Available on crate feature NSResponder only.
pub fn addSubview(&self, view: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn sortSubviewsUsingFunction_context( &self, compare: unsafe extern "C-unwind" fn(NonNull<NSView>, NonNull<NSView>, *mut c_void) -> NSComparisonResult, context: *mut c_void, )

Available on crate feature NSResponder only.
Safety
  • compare must be implemented correctly.
  • context must be a valid pointer or null.
pub fn viewDidMoveToWindow(&self)

Available on crate feature NSResponder only.
pub fn viewWillMoveToSuperview(&self, new_superview: Option<&NSView>)

Available on crate feature NSResponder only.
pub fn viewDidMoveToSuperview(&self)

Available on crate feature NSResponder only.
pub fn didAddSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub fn willRemoveSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub fn removeFromSuperview(&self)

Available on crate feature NSResponder only.
pub fn replaceSubview_with(&self, old_view: &NSView, new_view: &NSView)

Available on crate feature NSResponder only.
pub fn removeFromSuperviewWithoutNeedingDisplay(&self)

Available on crate feature NSResponder only.
pub fn viewDidChangeBackingProperties(&self)

Available on crate feature NSResponder only.
pub fn postsFrameChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPostsFrameChangedNotifications( &self, posts_frame_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub fn resizeSubviewsWithOldSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub fn resizeWithOldSuperviewSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub fn autoresizesSubviews(&self) -> bool

Available on crate feature NSResponder only.
pub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)

Available on crate feature NSResponder only.

Setter for autoresizesSubviews.

pub fn autoresizingMask(&self) -> NSAutoresizingMaskOptions

Available on crate feature NSResponder only.
pub fn setAutoresizingMask(&self, autoresizing_mask: NSAutoresizingMaskOptions)

Available on crate feature NSResponder only.

Setter for autoresizingMask.

pub fn setFrameOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub fn setFrameSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub fn frame(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setFrame(&self, frame: CGRect)

Available on crate feature NSResponder only.

Setter for frame.

pub fn setBoundsOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub fn setBoundsSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub fn translateOriginToPoint(&self, translation: CGPoint)

Available on crate feature NSResponder only.
pub fn scaleUnitSquareToSize(&self, new_unit_size: CGSize)

Available on crate feature NSResponder only.
pub fn bounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setBounds(&self, bounds: CGRect)

Available on crate feature NSResponder only.

Setter for bounds.

pub fn isFlipped(&self) -> bool

Available on crate feature NSResponder only.
pub fn isRotatedFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub fn isRotatedOrScaledFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub fn isOpaque(&self) -> bool

Available on crate feature NSResponder only.
pub fn convertPoint_fromView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPoint_toView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSize_fromView( &self, size: CGSize, view: Option<&NSView>, ) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSize_toView(&self, size: CGSize, view: Option<&NSView>) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRect_fromView( &self, rect: CGRect, view: Option<&NSView>, ) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRect_toView(&self, rect: CGRect, view: Option<&NSView>) -> CGRect

Available on crate feature NSResponder only.
pub fn backingAlignedRect_options( &self, rect: CGRect, options: NSAlignmentOptions, ) -> CGRect

Available on crate feature NSResponder only.
pub fn centerScanRect(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSizeToBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSizeFromBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRectToBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSizeToLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSizeFromLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRectToLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn canDrawConcurrently(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setCanDrawConcurrently(&self, can_draw_concurrently: bool)

Available on crate feature NSResponder only.

Setter for canDrawConcurrently.

pub fn canDraw(&self) -> bool

👎Deprecated:

If a view needs display, -drawRect: or -updateLayer will be called automatically when the view is able to draw. To check whether a view is in a window, call -window. To check whether a view is hidden, call -isHiddenOrHasHiddenAncestor.

Available on crate feature NSResponder only.
pub fn setNeedsDisplayInRect(&self, invalid_rect: CGRect)

Available on crate feature NSResponder only.
pub fn needsDisplay(&self) -> bool

Available on crate feature NSResponder only.
pub fn setNeedsDisplay(&self, needs_display: bool)

Available on crate feature NSResponder only.

Setter for needsDisplay.

pub fn lockFocus(&self)

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn unlockFocus(&self)

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn lockFocusIfCanDraw(&self) -> bool

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn visibleRect(&self) -> CGRect

Available on crate feature NSResponder only.

The portion of the view that isn’t clipped by its superviews.

Visibility, as reflected by this property, doesn’t account for whether other view or window objects overlap the current view or whether the current view is installed in a window at all. This value of this property is NSZeroRect if the current view is effectively hidden.

During a printing operation, the visible rectangle is further clipped to the page being imaged.

pub fn display(&self)

Available on crate feature NSResponder only.
pub fn displayIfNeeded(&self)

Available on crate feature NSResponder only.
pub fn displayIfNeededIgnoringOpacity(&self)

Available on crate feature NSResponder only.
pub fn displayRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayIfNeededInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayIfNeededInRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn drawRect(&self, dirty_rect: CGRect)

Available on crate feature NSResponder only.
pub fn viewWillDraw(&self)

Available on crate feature NSResponder only.
pub fn scrollPoint(&self, point: CGPoint)

Available on crate feature NSResponder only.
pub fn scrollRectToVisible(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn adjustScroll(&self, new_visible: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn scrollRect_by(&self, rect: CGRect, delta: CGSize)

👎Deprecated:

Use NSScrollView to achieve scrolling views.

Available on crate feature NSResponder only.
pub fn translateRectsNeedingDisplayInRect_by( &self, clip_rect: CGRect, delta: CGSize, )

Available on crate feature NSResponder only.
pub fn hitTest(&self, point: CGPoint) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub fn mouse_inRect(&self, point: CGPoint, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn viewWithTag(&self, tag: isize) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub fn tag(&self) -> isize

Available on crate feature NSResponder only.
pub fn needsPanelToBecomeKey(&self) -> bool

Available on crate feature NSResponder only.
pub fn mouseDownCanMoveWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn acceptsTouchEvents(&self) -> bool

👎Deprecated:

Use allowedTouchTypes instead

Available on crate feature NSResponder only.
pub fn setAcceptsTouchEvents(&self, accepts_touch_events: bool)

👎Deprecated:

Use allowedTouchTypes instead

Available on crate feature NSResponder only.

Setter for acceptsTouchEvents.

pub fn wantsRestingTouches(&self) -> bool

Available on crate feature NSResponder only.
pub fn setWantsRestingTouches(&self, wants_resting_touches: bool)

Available on crate feature NSResponder only.

Setter for wantsRestingTouches.

pub fn layerContentsRedrawPolicy(&self) -> NSViewLayerContentsRedrawPolicy

Available on crate feature NSResponder only.
pub fn setLayerContentsRedrawPolicy( &self, layer_contents_redraw_policy: NSViewLayerContentsRedrawPolicy, )

Available on crate feature NSResponder only.
pub fn layerContentsPlacement(&self) -> NSViewLayerContentsPlacement

Available on crate feature NSResponder only.
pub fn setLayerContentsPlacement( &self, layer_contents_placement: NSViewLayerContentsPlacement, )

Available on crate feature NSResponder only.
pub fn wantsLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn setWantsLayer(&self, wants_layer: bool)

Available on crate feature NSResponder only.

Setter for wantsLayer.

pub fn wantsUpdateLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn updateLayer(&self)

Available on crate feature NSResponder only.
pub fn canDrawSubviewsIntoLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn setCanDrawSubviewsIntoLayer(&self, can_draw_subviews_into_layer: bool)

Available on crate feature NSResponder only.
pub fn layoutSubtreeIfNeeded(&self)

Available on crate feature NSResponder only.
pub fn layout(&self)

Available on crate feature NSResponder only.
pub fn needsLayout(&self) -> bool

Available on crate feature NSResponder only.
pub fn setNeedsLayout(&self, needs_layout: bool)

Available on crate feature NSResponder only.

Setter for needsLayout.

pub fn layerUsesCoreImageFilters(&self) -> bool

Available on crate feature NSResponder only.
pub fn setLayerUsesCoreImageFilters(&self, layer_uses_core_image_filters: bool)

Available on crate feature NSResponder only.
pub fn clipsToBounds(&self) -> bool

Available on crate feature NSResponder only.
pub fn setClipsToBounds(&self, clips_to_bounds: bool)

Available on crate feature NSResponder only.

Setter for clipsToBounds.

pub fn postsBoundsChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPostsBoundsChangedNotifications( &self, posts_bounds_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub fn toolTip(&self) -> Option<Retained<NSString>>

Available on crate feature NSResponder only.
pub fn setToolTip(&self, tool_tip: Option<&NSString>)

Available on crate feature NSResponder only.

Setter for toolTip.

This is copied when set.

pub unsafe fn addToolTipRect_owner_userData( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, ) -> isize

Available on crate feature NSResponder only.
Safety
  • owner should be of the correct type.
  • data must be a valid pointer or null.
pub fn removeToolTip(&self, tag: isize)

Available on crate feature NSResponder only.
pub fn removeAllToolTips(&self)

Available on crate feature NSResponder only.
pub fn viewWillStartLiveResize(&self)

Available on crate feature NSResponder only.
pub fn viewDidEndLiveResize(&self)

Available on crate feature NSResponder only.
pub fn inLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn preservesContentDuringLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn rectPreservedDuringLiveResize(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn rectForSmartMagnificationAtPoint_inRect( &self, location: CGPoint, visible_rect: CGRect, ) -> CGRect

Available on crate feature NSResponder only.
pub fn prepareForReuse(&self)

Available on crate feature NSResponder only.
pub fn prepareContentInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn preparedContentRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setPreparedContentRect(&self, prepared_content_rect: CGRect)

Available on crate feature NSResponder only.

Setter for preparedContentRect.

pub fn allowsVibrancy(&self) -> bool

Available on crate feature NSResponder only.
pub fn viewDidChangeEffectiveAppearance(&self)

Available on crate feature NSResponder only.

Override point for reacting to the effective appearance of the receiver changing. At this point effectiveAppearance property reflects the new appearance.

pub unsafe fn nextKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn setNextKeyView(&self, next_key_view: Option<&NSView>)

Available on crate feature NSResponder only.

Setter for nextKeyView.

Safety

This is unretained, you must ensure the object is kept alive while in use.

pub unsafe fn previousKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn nextValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn previousValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn canBecomeKeyView(&self) -> bool

Available on crate feature NSResponder only.
pub fn setKeyboardFocusRingNeedsDisplayInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn drawFocusRingMask(&self)

Available on crate feature NSResponder only.
pub fn focusRingMaskBounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn noteFocusRingMaskChanged(&self)

Available on crate feature NSResponder only.
pub fn dataWithEPSInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub fn dataWithPDFInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub unsafe fn print(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
Safety

sender should be of the correct type.

pub unsafe fn knowsPageRange(&self, range: *mut NSRange) -> bool

Available on crate feature NSResponder only.
Safety

range must be a valid pointer.

pub fn rectForPage(&self, page: isize) -> CGRect

Available on crate feature NSResponder only.
pub fn locationOfPrintRect(&self, rect: CGRect) -> CGPoint

Available on crate feature NSResponder only.
pub fn drawPageBorderWithSize(&self, border_size: CGSize)

Available on crate feature NSResponder only.
pub fn pageHeader(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub fn pageFooter(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub fn drawSheetBorderWithSize(&self, border_size: CGSize)

👎Deprecated:

This is never invoked and the NSView implementation does nothing

Available on crate feature NSResponder only.
  • This method is obsolete. It will never be invoked from within AppKit, and NSView’s implementation of it does nothing. **
pub fn printJobTitle(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn beginDocument(&self)

Available on crate feature NSResponder only.
pub fn endDocument(&self)

Available on crate feature NSResponder only.
pub fn beginPageInRect_atPlacement(&self, rect: CGRect, location: CGPoint)

Available on crate feature NSResponder only.
pub fn endPage(&self)

Available on crate feature NSResponder only.
pub fn unregisterDraggedTypes(&self)

Available on crate feature NSResponder only.
pub unsafe fn exitFullScreenModeWithOptions( &self, options: Option<&NSDictionary<NSString>>, )

Available on crate feature NSResponder only.
Safety

options generic should be of the correct type.

pub fn isInFullScreenMode(&self) -> bool

Available on crate feature NSResponder only.
pub fn showDefinitionForAttributedString_atPoint( &self, attr_string: Option<&NSAttributedString>, text_baseline_origin: CGPoint, )

Available on crate feature NSResponder only.
pub fn isDrawingFindIndicator(&self) -> bool

Available on crate feature NSResponder only.
pub fn safeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub fn additionalSafeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub fn setAdditionalSafeAreaInsets( &self, additional_safe_area_insets: NSEdgeInsets, )

Available on crate feature NSResponder only.
pub fn safeAreaRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn prefersCompactControlSizeMetrics(&self) -> bool

Available on crate feature NSResponder only.

When this property is true, any NSControls in the view or its descendants will be sized with compact metrics compatible with macOS 15 and earlier. Defaults to false

pub fn setPrefersCompactControlSizeMetrics( &self, prefers_compact_control_size_metrics: bool, )

Available on crate feature NSResponder only.
pub fn updateTrackingAreas(&self)

Available on crate feature NSResponder only.
pub fn discardCursorRects(&self)

Available on crate feature NSResponder only.
pub fn resetCursorRects(&self)

Available on crate feature NSResponder only.
pub unsafe fn addTrackingRect_owner_userData_assumeInside( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, flag: bool, ) -> isize

Available on crate feature NSResponder only.
Safety
  • owner should be of the correct type.
  • data must be a valid pointer or null.
pub fn removeTrackingRect(&self, tag: isize)

Available on crate feature NSResponder only.
pub fn convertPointToBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertPointFromBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertSizeToBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertSizeFromBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertRectToBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertRectFromBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated:

This has always returned NO and had no effect on macOS

Available on crate feature NSResponder only.
pub fn shouldDrawColor(&self) -> bool

👎Deprecated:

This method no longer does anything

Available on crate feature NSResponder only.
pub fn gState(&self) -> isize

👎Deprecated
Available on crate feature NSResponder only.
pub fn allocateGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub fn setUpGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub fn renewGState(&self)

👎Deprecated
Available on crate feature NSResponder only.

Methods from Deref<Target = NSResponder>

pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>

Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)

Setter for nextResponder.

Safety

This is unretained, you must ensure the object is kept alive while in use.

pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool

Safety
  • action must be a valid selector.
  • object should be of the correct type.
pub unsafe fn noResponderFor(&self, event_selector: Sel)

Safety

event_selector must be a valid selector.

pub fn acceptsFirstResponder(&self) -> bool

pub fn becomeFirstResponder(&self) -> bool

pub fn resignFirstResponder(&self) -> bool

pub fn flushBufferedKeyEvents(&self)

pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub fn presentError(&self, error: &NSError) -> bool

pub fn willPresentError(&self, error: &NSError) -> Retained<NSError>

pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated:

This has always returned NO and had no effect on macOS

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}